pub struct ReviewGate {
pub reason: GateReason,
pub gate: ReviewGate,
}Expand description
Specific care-review gate created from missing or sensitive boarding profile evidence.
Fields
reason: GateReasonCare-profile reason that triggered the gate.
gate: ReviewGateHuman review category required to clear this care issue.
Implementations
Sourceimpl ReviewGate
impl ReviewGate
Sourcepub const fn new(reason: GateReason, gate: ReviewGate) -> Self
pub const fn new(reason: GateReason, gate: ReviewGate) -> Self
Creates a care-review gate with the operational reason and required review category.